==> haskell-lens-action-0.2.6-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-BQHdCv1ITLtIY2klHtbpgr
key:                  lens-action-0.2.6-BQHdCv1ITLtIY2klHtbpgr
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  5d318a99ce7482f47b94c78c3f3e7a17
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-BQHdCv1ITLtIY2klHtbpgr
depends:
    base-4.17.2.1 comonad-5.0.8-FaXCdIH358gBTaN3fXTS5x
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.2.3-CUB7er19pGW1jvefO3TVCG mtl-2.2.2
    profunctors-5.6.2-FU1ZJ7jAwY3FBezLPRDd4l
    semigroupoids-6.0.0.1-6AK4WuDDdcpGLtBowKfvAR transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-2CkL4fruGbBLhFy4k9xYvq
key:                  lens-action-0.2.6-2CkL4fruGbBLhFy4k9xYvq
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  c1e58fce682120fc25e70d091a51c7f5
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-2CkL4fruGbBLhFy4k9xYvq
depends:
    base-4.17.2.1 comonad-5.0.8-AikjgOvrhZ0DSXgM6149OA
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv mtl-2.2.2
    profunctors-5.6.2-1tzl2Ww27cFnwJWmZ0Rnv
    semigroupoids-6.0.0.1-37Ao1NEAslG3YMRVLWdZkr transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
